@@ -1,11 +1,13 @@
 import logging
 from typing import List, Dict, Type, Tuple
 import tensorflow as tf
-from tensorflow.keras.layers import Layer, MultiHeadAttention
+from keras.layers import Layer, MultiHeadAttention
 
-from keras.layers.pooling import Pooling2D, Pooling1D, Pooling3D
-from keras.saving.saved_model.load import RevivedLayer
-from keras.layers.convolutional import Conv
+from keras.layers.pooling.base_pooling1d import Pooling1D
+from keras.layers.pooling.base_pooling2d import Pooling2D
+from keras.layers.pooling.base_pooling3d import Pooling3D
+from keras.saving.legacy.saved_model.load import RevivedLayer
+from keras.layers.convolutional.base_conv import Conv
 from keras_data_format_converter.layers.confighandlers.dataformat import handle_data_format
 
 
