@@ -6,7 +6,7 @@ from keras.engine.keras_tensor import KerasTensor
 from keras.layers.core import TFOpLambda
 
 from tensorflow import keras, TensorShape
-from tensorflow.keras.layers import Layer, InputLayer, Input, MultiHeadAttention
+from keras.layers import Layer, InputLayer, Input, MultiHeadAttention
 from tensorflow.python.keras.engine.node import Node
 
 from keras_data_format_converter.layers.layer_utils import convert_layer, onnx_channel_first_cant_run_on_cpu_layers
@@ -68,48 +68,38 @@ class ModelConverter:
 
         return node_input_tensor_names.index(tensor_name)
 
-    def _fix_args(self, call_args: Tuple, node_input_tensors: List[KerasTensor]) -> Tuple[List, List[KerasTensor]]:
-        new_tfoplambda_args = list(call_args)
-        for i, arg in enumerate(call_args):
-            if isinstance(arg, dict):
-                new_arg_dict, node_input_tensors = self._fix_kwargs(arg, node_input_tensors)
-                new_tfoplambda_args[i] = new_arg_dict
-            if isinstance(arg, list):
-                new_arg, node_input_tensors = self._fix_args(arg, node_input_tensors)
-                new_tfoplambda_args[i] = new_arg
-            elif isinstance(arg, KerasTensor):
-                try:
-                    tensor_index = self._find_tensor_index_by_name(node_input_tensors, arg.name)
-                    new_tfoplambda_args[i] = node_input_tensors.pop(tensor_index)
-                except (IndexError, ValueError):
-                    pass
-        return new_tfoplambda_args, node_input_tensors
+    def _replace_tensors_in_call_args(self, call_args: Union[List, Dict], node_input_tensors: List[KerasTensor]
+                                      ) -> Tuple[Union[List, Dict], List[KerasTensor]]:
+        new_args = call_args.copy()
+        if isinstance(new_args, dict):
+            args_to_enumerate = new_args.values()
+            args_keys = new_args.keys()
+        else:
+            args_to_enumerate = new_args
+            args_keys = range(len(args_to_enumerate))
 
-    def _fix_kwargs(self, call_kwargs, node_input_tensors):
-        new_tfoplambda_kwargs = call_kwargs.copy()
-        for key, arg in call_kwargs.items():
-            if isinstance(arg, dict):
-                new_arg_dict, node_input_tensors = self._fix_kwargs(arg, node_input_tensors)
-                new_tfoplambda_kwargs[key] = new_arg_dict
-            elif isinstance(arg, list):
-                new_arg, node_input_tensors = self._fix_args(arg, node_input_tensors)
-                new_tfoplambda_kwargs[key] = new_arg
+        for i_k, arg in zip(args_keys, args_to_enumerate):
+            if isinstance(arg, (dict, list)):
+                new_arg, node_input_tensors = self._replace_tensors_in_call_args(arg, node_input_tensors)
+                new_args[i_k] = new_arg
             elif isinstance(arg, KerasTensor):
                 try:
                     tensor_index = self._find_tensor_index_by_name(node_input_tensors, arg.name)
-                    new_tfoplambda_kwargs[key] = node_input_tensors.pop(tensor_index)
+                    new_args[i_k] = node_input_tensors.pop(tensor_index)
                 except (IndexError, ValueError):
                     pass
-        return new_tfoplambda_kwargs, node_input_tensors
+        return new_args, node_input_tensors
 
     def _default_call_layer_by_args(self,
                                     converted_layer: Layer, call_args: Tuple, call_kwargs: Dict,
                                     node_input_tensors: List[KerasTensor]) -> KerasTensor:
-        new_tfoplambda_args, input_tensors = self._fix_args(call_args, node_input_tensors)
-        new_tfoplambda_kwargs, input_tensors = self._fix_kwargs(call_kwargs, node_input_tensors)
-        assert len(input_tensors) == 0
+        new_call_args, input_tensors = self._replace_tensors_in_call_args(list(call_args), node_input_tensors)
+        new_kwargs, input_tensors = self._replace_tensors_in_call_args(call_kwargs, node_input_tensors)
+        if len(node_input_tensors) > 0:
+            raise Exception(f"Failed to call layer {converted_layer.name}. "
+                            f"Couldn't find a match for some input tensors")
 
-        return converted_layer(*new_tfoplambda_args, **new_tfoplambda_kwargs)
+        return converted_layer(*new_call_args, **new_kwargs)
 
     def _call_layer_by_args(
             self, converted_layer: Layer, node_input_tensors: Union[KerasTensor, List[KerasTensor]],
